@@ -25,7 +25,7 @@
 #[macro_export]
 macro_rules! static_assert {
     (let $e:expr; ) => (
-        type ArrayForStaticAssert_ = [i8; 0 - ((false == ($e)) as usize)];
+        type _ArrayForStaticAssert = [i8; 0 - ((false == ($e)) as usize)];
     );
 
     (let $e:expr; $e1:expr $(, $ee:expr)*) => (
@@ -36,3 +36,13 @@ macro_rules! static_assert {
         static_assert!(let $e; $($ee),*);
     );
 }
+
+#[cfg(test)]
+mod tests {
+    const _FOUR: i32 = 4;
+
+    #[test]
+    fn test_0() {
+        static_assert!(1 + 2 == { _FOUR - 1 }, 2 < 3);
+    }
+}
